package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Config;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.DeviceGroupMapper;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.KeywordTempMapper;
import com.datacloudsec.scan.dao.LogMapper;
import com.datacloudsec.scan.dao.PwddicMapper;
import com.datacloudsec.scan.dao.WebBugMapper;
import com.datacloudsec.scan.dao.WebMapper;
import com.datacloudsec.scan.dao.WebProxyMapper;
import com.datacloudsec.scan.dao.WebTempMapper;
import com.datacloudsec.scan.entity.LicCmp;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IWeb;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.PeriodTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.scan.tasks.scheduler.job.ScanJob;
import com.datacloudsec.scan.tasks.scheduler.time.TimeIntervalHour;
import com.datacloudsec.scan.tasks.scheduler.time.TimeMonthly;
import com.datacloudsec.scan.tasks.scheduler.time.TimeMutilDay;
import com.datacloudsec.scan.tasks.scheduler.time.TimeWeek;
import com.datacloudsec.utils.ComonZipUtil;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SecretUtil;
import com.datacloudsec.utils.SerializeUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;
import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;
import org.dom4j.io.OutputFormat;
import org.dom4j.io.XMLWriter;
import sun.misc.BASE64Encoder;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/WebService.class */
public class WebService extends TaskBaseService implements IWeb {
    private Logger LOG = Logger.getLogger(WebService.class);
    private WebMapper webMapper = (WebMapper) InstanceUtil.newDaoInstance(WebMapper.class);
    private WebBugMapper webBugMapper = (WebBugMapper) InstanceUtil.newDaoInstance(WebBugMapper.class);
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private DeviceGroupMapper deviceGroupMapper = (DeviceGroupMapper) InstanceUtil.newDaoInstance(DeviceGroupMapper.class);
    private KeywordTempMapper keywordTempMapper = (KeywordTempMapper) InstanceUtil.newDaoInstance(KeywordTempMapper.class);
    private WebTempMapper webTempMapper = (WebTempMapper) InstanceUtil.newDaoInstance(WebTempMapper.class);
    private WebProxyMapper webProxyMapper = (WebProxyMapper) InstanceUtil.newDaoInstance(WebProxyMapper.class);
    private WebBugMapper bugMapper = (WebBugMapper) InstanceUtil.newDaoInstance(WebBugMapper.class);
    private IEngine engine = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);
    private PwddicMapper pwddicMapper = (PwddicMapper) InstanceUtil.newDaoInstance(PwddicMapper.class);
    private LogMapper logMapper = (LogMapper) InstanceUtil.newDaoInstance(LogMapper.class);

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        int n = this.webMapper.getWebTaskDevCount(id).intValue();
        if (n > 0) {
            throw new UEException("该任务中有" + n + "个资产正在扫描，请先停止该任务中所有正在扫描的资产再删除！");
        }
        delTask(session, id, version);
    }

    public Integer insert(HttpSession session, String name, String desct, Integer type, String dest, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, Integer kid, String webList, String periodTime, String tamperTime, String availTime, String emailcheck, String smscheck, String tamper, Integer similarity, Integer hiddenLinkCheckDepth, String keyset, String avail, String confContent, String warningType, Integer val1, String ftpReportType) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("webscan")) {
            throw new UEException("网站任务未授权");
        }
        LicCmp licCmp = getLicCp(cmp, "webscan");
        if (InitSystemTask.licenseApp.valudate(licCmp.getAuthDay()) != 0) {
            throw new UEException("网站任务授权已过期");
        }
        User user = null;
        try {
            user = (User) session.getAttribute("userInfo");
            Integer count = this.webMapper.getTaskCountByName(name, 0, user.getId(), (Integer) null);
            if (count != null && count.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        } catch (Exception e) {
            Integer count2 = this.webMapper.getTcountForOthers(name, 0, (Integer) null);
            if (count2 != null && count2.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        }
        Integer taskid = add(null, name, desct, type, dest, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, kid, webList, periodTime, tamperTime, availTime, emailcheck, smscheck, tamper, similarity, hiddenLinkCheckDepth, keyset, null, 0, avail, confContent, warningType, val1, ftpReportType, session);
        if (type.intValue() == 1) {
            boolean bl = true;
            List<Map<String, Object>> taskWebList = this.webMapper.getTaskDevByTid(taskid);
            String licType = params.get("type");
            for (Map<String, Object> map : taskWebList) {
                Integer devid = ObjectUtil.getInt(map.get("id"));
                try {
                    if ("tool".equalsIgnoreCase(licType)) {
                        startWeb(devid);
                    } else {
                        if (dest.contains("bug") || dest.contains("horse") || dest.contains("keyword") || dest.contains("fish")) {
                            startWeb(devid);
                        }
                        if (dest.contains("avail")) {
                            startAvail(devid);
                        }
                        if (dest.contains("tamper")) {
                            startTamper(devid);
                        }
                    }
                } catch (Exception e2) {
                    bl = false;
                    this.LOG.error("立即扫描异常URL（" + map.get("url") + "）：", e2);
                }
            }
            if (bl) {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描网站任务", "", 1, "扫描成功");
            } else {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描网站任务", "", 2, "扫描失败");
            }
        } else {
            if (dest.contains("bug") || dest.contains("horse") || dest.contains("keyword") || dest.contains("fish")) {
                startWebScanTimer(taskid, type, periodTime, alarmType, alarmMethod, alarmTime, "bug");
            }
            if (dest.contains("tamper")) {
                startWebScanTimer(taskid, type, tamperTime, alarmType, alarmMethod, alarmTime, "tamper");
            }
            if (dest.contains("avail")) {
                startWebScanTimer(taskid, type, availTime, alarmType, alarmMethod, alarmTime, "avail");
            }
        }
        startWebAlermTimer(taskid, alarmType, alarmMethod, alarmTime, "all");
        return taskid;
    }

    private Integer add(Integer id, String name, String desct, Integer type, String destOld, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, Integer kid, String webList, String periodTime, String tamperTime, String availTime, String emailcheck, String smscheck, String tamper, Integer similarity, Integer hiddenLinkCheckDepth, String keyset, Integer version, Integer taskType, String avail, String confContent, String warningType, Integer val1, String ftpReportType, HttpSession session) throws Exception {
        String url;
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "webscan");
        String licType = params.get("type");
        int maxdevice = licCmp.getMaxdevice();
        User user = (User) session.getAttribute("userInfo");
        String rule = DataRule.getRuleWhere(session, "t_task");
        List<String> destList = new ArrayList<>();
        String licMod = ObjectUtil.getString(params.get("mod"), "");
        if (licMod.contains("bug") && destOld.contains("bug")) {
            destList.add("bug");
        }
        if (licMod.contains("hidelink") && destOld.contains("horse")) {
            destList.add("horse");
        }
        if (licMod.contains("keyword") && destOld.contains("keyword")) {
            destList.add("keyword");
        }
        if (licMod.contains("tamper") && destOld.contains("tamper")) {
            destList.add("tamper");
        }
        if (licMod.contains("usable") && destOld.contains("avail")) {
            destList.add("avail");
        }
        if (licMod.contains("fish") && destOld.contains("fish")) {
            destList.add("fish");
        }
        String dest = StringUtils.join(destList, ",");
        Task task = new Task();
        task.setName(name);
        if (id != null) {
            task.setId(id);
        }
        task.setDesct(desct);
        task.setType(type);
        task.setAlarmMethod(alarmMethod);
        task.setAlarmType(alarmType);
        task.setAlarmTime(alarmTime);
        task.setMailAddr(emailcheck);
        task.setSmsAddr(smscheck);
        task.setPeriodTime(periodTime);
        task.setTamperTime(tamperTime);
        task.setAvailTime(availTime);
        if (user != null) {
            task.setUid(user.getId());
        }
        task.setTaskType(taskType);
        task.setVersion(version);
        task.setRule(rule);
        task.setConfContent(confContent);
        task.setDest(dest);
        task.setTamper(tamper);
        task.setSimilarity(similarity);
        task.setHiddenLinkCheckDepth(hiddenLinkCheckDepth);
        task.setKeyset(keyset);
        task.setAvail(avail);
        task.setKid(kid);
        task.setWarningType(warningType);
        task.setVal1(val1);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        task.setFtpReportType(ftpReportType);
        if (id != null) {
            task.setId(id);
        }
        if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
            task.setDest("bug");
            task.setTamper((String) null);
            task.setSimilarity((Integer) null);
            task.setHiddenLinkCheckDepth((Integer) null);
        }
        SqlSession sqlsession = null;
        try {
            try {
                sqlsession = MybatisUtil.sqlSessionFactory.openSession();
                WebMapper webMapper = (WebMapper) sqlsession.getMapper(WebMapper.class);
                DeviceMapper deviceMapper = (DeviceMapper) sqlsession.getMapper(DeviceMapper.class);
                if (id == null) {
                    List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(webList, ArrayList.class);
                    int devIpCount = 0;
                    for (Map<String, Object> webMap : devListMap) {
                        if (webMap.containsKey("id")) {
                            Map<String, Object> map = deviceMapper.getDevById(ObjectUtil.getInt(webMap.get("id")));
                            if (map != null) {
                                Map<String, Object> confMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map.get("confContent"), ""), HashMap.class);
                                url = IPUtil.urlFormat(ObjectUtil.getString(((Map) confMap.get(ReportService.REPORT_STATE_SUCCESS)).get("url"), ""));
                            } else {
                                url = IPUtil.urlFormat(ObjectUtil.getString(webMap.get("url"), ""));
                            }
                        } else {
                            url = IPUtil.urlFormat(ObjectUtil.getString(webMap.get("url"), ""));
                        }
                        if (user != null && StringUtils.isNotBlank(user.getUrls()) && !Arrays.asList(user.getUrls().split("\n")).contains(url)) {
                            throw new UEException("网站地址【" + url + "】不在扫描范围内，可联系管理员授权扫描此IP");
                        }
                        devIpCount++;
                    }
                    if (maxdevice > 0 && webMapper.getCountByType(ReportService.REPORT_STATE_SUCCESS) + devIpCount > maxdevice) {
                        throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
                    }
                    webMapper.insert(task);
                    for (Map<String, Object> webMap2 : devListMap) {
                        if (webMap2.containsKey("id")) {
                            Map<String, Object> map2 = deviceMapper.getDevById(ObjectUtil.getInt(webMap2.get("id")));
                            if (map2 != null) {
                                Map<String, Object> devGroup = this.deviceGroupMapper.getDevGroupById(ObjectUtil.getInt(map2.get("dgid")));
                                map2.put("devgroup", ObjectUtil.getString(devGroup.get("name"), ""));
                                map2.put("type", 1);
                                map2.put("taskId", task.getId());
                                map2.put("did", ObjectUtil.getInt(map2.get("id")));
                                Map<String, Object> confMap2 = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map2.get("confContent"), ""), HashMap.class);
                                Map<String, Object> webConfig = (Map) confMap2.get(ReportService.REPORT_STATE_SUCCESS);
                                String url2 = IPUtil.urlFormat(ObjectUtil.getString(webConfig.get("url"), ""));
                                webConfig.put("whiteList", IPUtil.urlFormat(ObjectUtil.getString(webConfig.get("whiteList"), "")));
                                webConfig.put("url", url2);
                                map2.put("ip", url2);
                                map2.put("confContent", JsonUtil.MAPPER.writeValueAsString(webConfig));
                                webMapper.insertTaskDevice(map2);
                            } else {
                                Map<String, Object> dmap = new HashMap<>();
                                String url3 = IPUtil.urlFormat(ObjectUtil.getString(webMap2.get("url"), ""));
                                dmap.put("name", url3.length() > 50 ? url3.substring(0, 50) : url3);
                                dmap.put("type", 1);
                                dmap.put("ip", ObjectUtil.getString(url3, "", 2000));
                                dmap.put("taskId", task.getId());
                                dmap.put("regionSid", Integer.valueOf((user == null || user.getRegionSid() == null) ? 110000 : user.getRegionSid().intValue()));
                                dmap.put("regionCid", Integer.valueOf((user == null || user.getRegionCid() == null) ? 110101 : user.getRegionCid().intValue()));
                                dmap.put("confContent", "{\"url\":\"" + url3 + "\"}");
                                webMapper.insertTaskDevice(dmap);
                            }
                        } else {
                            Map<String, Object> dmap2 = new HashMap<>();
                            String url4 = IPUtil.urlFormat(ObjectUtil.getString(webMap2.get("url"), ""));
                            dmap2.put("name", url4.length() > 50 ? url4.substring(0, 50) : url4);
                            dmap2.put("type", 1);
                            dmap2.put("taskId", task.getId());
                            dmap2.put("ip", ObjectUtil.getString(url4, "", 2000));
                            dmap2.put("regionSid", Integer.valueOf((user == null || user.getRegionSid() == null) ? 110000 : user.getRegionSid().intValue()));
                            dmap2.put("regionCid", Integer.valueOf((user == null || user.getRegionCid() == null) ? 110101 : user.getRegionCid().intValue()));
                            dmap2.put("confContent", "{\"url\":\"" + url4 + "\",\"extraUrls\":\"" + ObjectUtil.getString(webMap2.get("extraUrls"), "") + "\"}");
                            webMapper.insertTaskDevice(dmap2);
                        }
                    }
                } else {
                    Integer rcount = webMapper.update(task);
                    if (rcount != null && rcount.intValue() == 0) {
                        throw new UEException("数据已被修改或删除，请刷新页面或返回");
                    }
                }
                if (user != null) {
                    if (StringUtils.isNotBlank(mailAddr)) {
                        webMapper.delEmail(user.getId());
                        String[] mail = mailAddr.split(",");
                        for (String ml : mail) {
                            webMapper.insertEmail(ml, user.getId());
                        }
                    }
                    if (StringUtils.isNotBlank(smsAddr)) {
                        webMapper.delPhone(user.getId());
                        String[] sms = smsAddr.split(",");
                        for (String s : sms) {
                            webMapper.insertPhone(s, user.getId());
                        }
                    }
                }
                sqlsession.commit();
                return task.getId();
            } catch (Exception e) {
                if (sqlsession != null) {
                    sqlsession.rollback();
                }
                throw e;
            }
        } finally {
            if (sqlsession != null) {
                sqlsession.close();
            }
        }
    }

    public void insertTaskDev(Map<String, Object> map) throws Exception {
        this.webMapper.insertTaskDevice(map);
    }

    public void update(HttpSession session, Integer id, String name, String desct, Integer type, String dest, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, Integer kid, String periodTime, String tamperTime, String availTime, String emailcheck, String smscheck, String tamper, Integer similarity, Integer hiddenLinkCheckDepth, String keyset, Integer version, String avail, String confContent, String warningType, Integer val1, String ftpReportType) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.webMapper.getTaskCountByName(name, 0, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        add(id, name, desct, type, dest, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, kid, null, periodTime, tamperTime, availTime, emailcheck, smscheck, tamper, similarity, hiddenLinkCheckDepth, keyset, version, 0, avail, confContent, warningType, val1, ftpReportType, session);
        stopWebTimer(session, id);
        if (type.intValue() == 2) {
            if (dest.contains("bug") || dest.contains("horse") || dest.contains("keyword") || dest.contains("fish")) {
                startWebScanTimer(id, type, periodTime, alarmType, alarmMethod, alarmTime, "bug");
            }
            if (dest.contains("tamper")) {
                startWebScanTimer(id, type, tamperTime, alarmType, alarmMethod, alarmTime, "tamper");
            }
            if (dest.contains("avail")) {
                startWebScanTimer(id, type, availTime, alarmType, alarmMethod, alarmTime, "avail");
            }
        }
        startWebAlermTimer(id, alarmType, alarmMethod, alarmTime, "all");
    }

    public void startWebScanTimer(Integer taskid, Integer type, String periodTime, Integer alarmType, String alarmMethod, String alarmTime, String scanType) throws Exception {
        if (type.intValue() == 2) {
            String[] entryPeriod = periodTime.split(":");
            String periodId = "scan_" + scanType + taskid;
            if (periodTime.charAt(0) == '0') {
                Map<String, Object> map = new HashMap<>();
                map.put("taskid", taskid);
                map.put("scanType", scanType);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeMonthly(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map);
                return;
            }
            if (periodTime.charAt(0) == '1') {
                Map<String, Object> map2 = new HashMap<>();
                map2.put("taskid", taskid);
                map2.put("scanType", scanType);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeWeek(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map2);
                return;
            }
            if (periodTime.charAt(0) == '2') {
                Map<String, Object> map3 = new HashMap<>();
                map3.put("taskid", taskid);
                map3.put("scanType", scanType);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeMutilDay(0, ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue()), periodId, map3);
                return;
            }
            if (periodTime.charAt(0) == '3') {
                Map<String, Object> map4 = new HashMap<>();
                map4.put("taskid", taskid);
                map4.put("scanType", scanType);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeMutilDay(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), ObjectUtil.getInt(entryPeriod[3]).intValue()), periodId, map4);
                return;
            }
            if (periodTime.charAt(0) == '4') {
                Map<String, Object> map5 = new HashMap<>();
                map5.put("taskid", taskid);
                map5.put("scanType", scanType);
                PeriodTask.getInstance().addJob(ScanJob.class, new TimeIntervalHour(ObjectUtil.getInt(entryPeriod[1]).intValue(), ObjectUtil.getInt(entryPeriod[2]).intValue(), 0), periodId, map5);
            }
        }
    }

    public void startWebAlermTimer(Integer taskid, Integer alarmType, String alarmMethod, String alarmTime, String scanType) throws Exception {
        if (alarmType.intValue() == 2) {
            if (alarmMethod.contains("mail") || alarmMethod.contains("sms")) {
                String[] at = alarmTime.split(":");
                Map<String, Object> map = new HashMap<>();
                map.put("taskid", taskid);
                map.put("scanType", scanType);
                PeriodTask.getInstance().addJob(AlermJob.class, new TimeMutilDay(0, ObjectUtil.getInt(at[0]).intValue(), ObjectUtil.getInt(at[1]).intValue()), "alerm_" + scanType + taskid, map);
            }
        }
    }

    private void stopWebTimer(HttpSession session, Integer taskid) throws Exception {
        if (taskid == null) {
            List<Map<String, Object>> list = this.webMapper.searchTimer((Integer) null, DataRule.getRuleWhere(session, "t_task"));
            for (Map<String, Object> m : list) {
                Object tid = m.get("id");
                PeriodTask.getInstance().removeJob("alerm_all" + tid);
                PeriodTask.getInstance().removeJob("scan_bug" + tid);
                PeriodTask.getInstance().removeJob("scan_tamper" + tid);
                PeriodTask.getInstance().removeJob("scan_avail" + tid);
            }
            return;
        }
        PeriodTask.getInstance().removeJob("alerm_all" + taskid);
        PeriodTask.getInstance().removeJob("scan_bug" + taskid);
        PeriodTask.getInstance().removeJob("scan_tamper" + taskid);
        PeriodTask.getInstance().removeJob("scan_avail" + taskid);
    }

    public void startTamper(Integer devid) throws Exception {
        Map<String, Object> device = this.webMapper.getTaskDevById(devid);
        if (device == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        int status = ObjectUtil.getInt(device.get("tamperStatus"), 1);
        if (status != 1) {
            SqlSession session = null;
            try {
                try {
                    session = MybatisUtil.sqlSessionFactory.openSession(true);
                    WebBugMapper webBugMapper = (WebBugMapper) session.getMapper(WebBugMapper.class);
                    WebMapper webMapper = (WebMapper) session.getMapper(WebMapper.class);
                    webBugMapper.delUrlTamper2(devid);
                    Map<String, Object> map = new HashMap<>();
                    map.put("tamperOffset", 0);
                    map.put("tamperPro", 0);
                    map.put("devid", devid);
                    webMapper.updateTaskDevice(map);
                    session.commit();
                    if (session != null) {
                        session.close();
                    }
                    String config = ObjectUtil.getString(device.get("confContent"), "{}");
                    Map<String, String> taskOption = (Map) JsonUtil.MAPPER.readValue(config, new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.WebService.1
                    });
                    Task task = this.webMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                    Map<String, String> taskConf = (Map) JsonUtil.MAPPER.readValue(task.getConfContent(), new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.WebService.2
                    });
                    taskOption.putAll(taskConf);
                    taskOption.put("scanMode", "ExploreOnly");
                    taskOption.put("tamper", "yes");
                    taskOption.put("policies", "None");
                    Integer proxyId = ObjectUtil.getInt(taskOption.get("proxy"));
                    if (proxyId != null) {
                        taskOption.putAll((Map) JsonUtil.MAPPER_ESCAPE_HTML.readValue(this.webProxyMapper.getPrxyConfigById(proxyId), HashMap.class));
                    }
                    try {
                        IEngine.EngineResult eresult = this.engine.webScan(ObjectUtil.getString(taskOption.get("url"), (String) null), ObjectUtil.getString(taskOption.get("method"), (String) null), ObjectUtil.getString(taskOption.get("referer"), (String) null), ObjectUtil.getString(taskOption.get("body"), (String) null), taskOption);
                        if (eresult != null) {
                            Map<String, Object> taskwebmap = new HashMap<>();
                            taskwebmap.put("devid", devid);
                            taskwebmap.put("tamperEngineid", eresult.getEngineId());
                            taskwebmap.put("tamperEid", Integer.valueOf(eresult.getLocalId()));
                            taskwebmap.put("tamperStatus", 1);
                            taskwebmap.put("tstartTime", new Date());
                            taskwebmap.put("tScanCount", Integer.valueOf(ObjectUtil.getInt(device.get("tScanCount"), 0) + 1));
                            this.webMapper.updateTaskDevice(taskwebmap);
                            return;
                        }
                        Map<String, Object> taskwebmap2 = new HashMap<>();
                        taskwebmap2.put("devid", devid);
                        taskwebmap2.put("tamperStatus", 4);
                        this.webMapper.updateTaskDevice(taskwebmap2);
                    } catch (Exception e) {
                        Object error = e instanceof UEException ? e.getMessage() : "连接引擎出错";
                        Map<String, Object> map2 = new HashMap<>();
                        map2.put("tamperErr", error);
                        map2.put("tamperStatus", 3);
                        map2.put("devid", devid);
                        this.webMapper.updateTaskDevice(map2);
                        this.LOG.error("", e);
                    }
                } catch (Exception e2) {
                    session.rollback();
                    throw e2;
                }
            } catch (Throwable th) {
                if (session != null) {
                    session.close();
                }
                throw th;
            }
        }
    }

    public void startAvail(Integer devid) throws Exception {
        Map<String, Object> device = this.webMapper.getTaskDevById(devid);
        if (device == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        int status = ObjectUtil.getInt(device.get("availStatus"), 1);
        if (status != 1) {
            Map<String, Object> map = new HashMap<>();
            map.put("availPro", 0);
            map.put("devid", devid);
            this.webMapper.updateTaskDevice(map);
            String config = ObjectUtil.getString(device.get("confContent"), "{}");
            Map<String, String> taskOption = (Map) JsonUtil.MAPPER.readValue(config, new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.WebService.3
            });
            taskOption.put("scanMode", "DetectOnly");
            taskOption.put("policies", "None");
            Integer proxyId = ObjectUtil.getInt(taskOption.get("proxy"));
            if (proxyId != null) {
                taskOption.putAll((Map) JsonUtil.MAPPER_ESCAPE_HTML.readValue(this.webProxyMapper.getPrxyConfigById(proxyId), HashMap.class));
            }
            try {
                IEngine.EngineResult eresult = this.engine.availScan(ObjectUtil.getString(taskOption.get("url"), (String) null), ObjectUtil.getString(taskOption.get("method"), (String) null), ObjectUtil.getString(taskOption.get("referer"), (String) null), ObjectUtil.getString(taskOption.get("body"), (String) null), taskOption);
                if (eresult != null) {
                    Map<String, Object> taskwebmap = new HashMap<>();
                    taskwebmap.put("devid", devid);
                    taskwebmap.put("availEngineid", eresult.getEngineId());
                    taskwebmap.put("availEid", Integer.valueOf(eresult.getLocalId()));
                    taskwebmap.put("availStatus", 1);
                    taskwebmap.put("astartTime", new Date());
                    taskwebmap.put("aScanCount", Integer.valueOf(ObjectUtil.getInt(device.get("aScanCount"), 0) + 1));
                    this.webMapper.updateTaskDevice(taskwebmap);
                    return;
                }
                Map<String, Object> taskwebmap2 = new HashMap<>();
                taskwebmap2.put("devid", devid);
                taskwebmap2.put("availStatus", 4);
                this.webMapper.updateTaskDevice(taskwebmap2);
            } catch (Exception e) {
                Object error = e instanceof UEException ? e.getMessage() : "连接引擎出错";
                Map<String, Object> emap = new HashMap<>();
                emap.put("availErr", error);
                emap.put("availStatus", 3);
                emap.put("devid", devid);
                this.webMapper.updateTaskDevice(emap);
                this.LOG.error("", e);
            }
        }
    }

    public void startWeb(Integer devid) throws Exception {
        Map<String, Object> device = this.webMapper.getTaskDevById(devid);
        if (device == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        int status = ObjectUtil.getInt(device.get("status"), 1);
        if (status != 1) {
            Task task = this.webMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
            SqlSession session = null;
            try {
                try {
                    session = MybatisUtil.sqlSessionFactory.openSession(true);
                    WebBugMapper webBugMapper = (WebBugMapper) session.getMapper(WebBugMapper.class);
                    WebMapper webMapper = (WebMapper) session.getMapper(WebMapper.class);
                    webBugMapper.delUrl2(devid);
                    webBugMapper.delBug2(devid);
                    Map<String, Object> dmap = new HashMap<>();
                    dmap.put("offset1", 0);
                    dmap.put("offset2", 0);
                    dmap.put("offset3", 0);
                    dmap.put("progress", 0);
                    dmap.put("devid", devid);
                    webMapper.updateTaskDevice(dmap);
                    session.commit();
                    if (session != null) {
                        session.close();
                    }
                    Map<? extends String, ? extends String> taskConf = (Map) JsonUtil.MAPPER.readValue(task.getConfContent(), new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.WebService.4
                    });
                    String config = ObjectUtil.getString(device.get("confContent"), "{}");
                    Map<String, String> taskOption = (Map) JsonUtil.MAPPER.readValue(config, new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.WebService.5
                    });
                    List<Map<String, Object>> cookies = this.deviceMapper.getCookiesByDeviceid(ObjectUtil.getInt(device.get("did")), (Integer) null, (Integer) null);
                    if (CollectionUtils.isNotEmpty(cookies)) {
                        String extraUrls = taskOption.get("extraUrls");
                        if (StringUtils.isNotBlank(extraUrls)) {
                            cookies.addAll((Collection) JsonUtil.MAPPER_ESCAPE_HTML.readValue(taskOption.get("extraUrls"), List.class));
                        }
                        taskConf.put("extraUrls", JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(cookies));
                    }
                    taskOption.putAll(taskConf);
                    String cate = taskOption.get("clientCertificate");
                    String cert = taskOption.get("clientCertificateCert");
                    File devFiledir = new File(Constant.COMMON_DIR, "device");
                    if ("PEM".equalsIgnoreCase(cate)) {
                        if (StringUtils.isNotBlank(cert)) {
                            taskOption.put("clientCertificateCert", FileUtils.readFileToString(new File(devFiledir, cert)));
                        }
                        String key = taskOption.get("clientCertificateKey");
                        if (StringUtils.isNotBlank(key)) {
                            taskOption.put("clientCertificateKey", FileUtils.readFileToString(new File(devFiledir, key)));
                        }
                    } else if ("PFX".equalsIgnoreCase(cate) && StringUtils.isNotBlank(cert)) {
                        taskOption.put("clientCertificateCert", new BASE64Encoder().encode(FileUtils.readFileToByteArray(new File(devFiledir, cert))));
                    }
                    Integer proxyId = ObjectUtil.getInt(taskOption.get("proxy"));
                    if (proxyId != null) {
                        taskOption.putAll((Map) JsonUtil.MAPPER_ESCAPE_HTML.readValue(this.webProxyMapper.getPrxyConfigById(proxyId), HashMap.class));
                    }
                    String taskDest = task.getDest();
                    if (taskDest.contains("bug")) {
                        Integer poliid = ObjectUtil.getInt(taskOption.get("policies"));
                        if (poliid != null) {
                            Map<String, Object> webTemp = this.webTempMapper.getWebTempById(poliid);
                            String policies = ObjectUtil.getString(webTemp.get("name_en"), "").replace(",", "`");
                            taskOption.put("policies", policies);
                        }
                    } else {
                        taskOption.put("policies", "None");
                    }
                    if (taskDest.contains("horse")) {
                        taskOption.put("Hiddenlink", "yes");
                        int hiddenLinkCheckDepth = ObjectUtil.getInt(task.getHiddenLinkCheckDepth(), 2);
                        taskOption.put("hiddenLinkCheckDepth", new StringBuilder(String.valueOf(hiddenLinkCheckDepth)).toString());
                    }
                    if (taskDest.contains("fish")) {
                        taskOption.put("FishingInspection", "yes");
                    }
                    if (taskDest.contains("keyword")) {
                        taskOption.put("KeyWords", "yes");
                        String keywords = null;
                        Integer kid = task.getKid();
                        if (kid.intValue() != 1) {
                            Map<String, Object> km = this.keywordTempMapper.getTemplateById(kid);
                            String keyPath = ObjectUtil.getString(km.get("path"), "");
                            if (!"".equals(keyPath)) {
                                keywords = FileUtils.readFileToString(new File(Constant.KEYWORDS_DIC, keyPath), "UTF-8");
                            } else {
                                keywords = ObjectUtil.getString(km.get("content"), "");
                            }
                        }
                        String keyset = task.getKeyset();
                        taskOption.put("keywordsCheckImage", keyset.contains("img") ? "Yes" : "No");
                        taskOption.put("keywordsCheckCard", keyset.contains("idCard") ? "Yes" : "No");
                        taskOption.put("keywords", keywords == null ? null : keywords.replace("|", "\r\n"));
                    }
                    if (taskDest.equals("fish")) {
                        taskOption.put("scanMode", "TestOnly");
                    }
                    if (taskOption.containsKey("webpwds")) {
                        Integer webPwdId = ObjectUtil.getInt(taskOption.get("webpwds"));
                        Map<String, Object> webPwd = this.pwddicMapper.getPwdGroupById(webPwdId);
                        if (MapUtils.isNotEmpty(webPwd)) {
                            Map<String, Object> webUserDic = this.pwddicMapper.getTemplateById(ObjectUtil.getInt(webPwd.get("upid")));
                            if (MapUtils.isNotEmpty(webUserDic)) {
                                try {
                                    taskOption.put("usernames", FileUtils.readFileToString(new File(Constant.PWDDIC_DIC, ObjectUtil.getString(webUserDic.get("path"), ""))));
                                } catch (Exception e) {
                                    taskOption.put("usernames", ObjectUtil.getString(webUserDic.get("content"), ""));
                                }
                            }
                            Map<String, Object> webPwdDic = this.pwddicMapper.getTemplateById(ObjectUtil.getInt(webPwd.get("ppid")));
                            if (MapUtils.isNotEmpty(webPwdDic)) {
                                try {
                                    taskOption.put("passwords", FileUtils.readFileToString(new File(Constant.PWDDIC_DIC, ObjectUtil.getString(webPwdDic.get("path"), ""))));
                                } catch (Exception e2) {
                                    taskOption.put("passwords", ObjectUtil.getString(webPwdDic.get("content"), ""));
                                }
                            }
                        }
                    }
                    if (taskOption.containsKey("guesspaths") && StringUtils.isNotBlank(ObjectUtil.getString(taskOption.get("guesspaths"), ""))) {
                        taskOption.put("guesspaths", FileUtils.readFileToString(new File(Constant.GUESSPATHS_DIR, taskOption.get("guesspaths")), "UTF-8"));
                    }
                    Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
                    String licType = params.get("type");
                    try {
                        IEngine.EngineResult eresult = this.engine.webScan(ObjectUtil.getString(taskOption.get("url"), (String) null), ObjectUtil.getString(taskOption.get("method"), (String) null), ObjectUtil.getString(taskOption.get("referer"), (String) null), ObjectUtil.getString(taskOption.get("postBody"), (String) null), taskOption);
                        if (eresult != null) {
                            Map<String, Object> taskwebmap = new HashMap<>();
                            taskwebmap.put("devid", devid);
                            taskwebmap.put("engineId", eresult.getEngineId());
                            taskwebmap.put("localEid", Integer.valueOf(eresult.getLocalId()));
                            taskwebmap.put("status", 1);
                            taskwebmap.put("startTime", new Date());
                            taskwebmap.put("scanCount", Integer.valueOf(ObjectUtil.getInt(device.get("scanCount"), 0) + 1));
                            if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
                                taskwebmap.put("availStatus", 1);
                                taskwebmap.put("aScanCount", Integer.valueOf(ObjectUtil.getInt(device.get("aScanCount"), 0) + 1));
                            }
                            this.webMapper.updateTaskDevice(taskwebmap);
                            return;
                        }
                        Map<String, Object> taskwebmap2 = new HashMap<>();
                        taskwebmap2.put("devid", devid);
                        taskwebmap2.put("status", 4);
                        if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
                            taskwebmap2.put("availStatus", 4);
                        }
                        this.webMapper.updateTaskDevice(taskwebmap2);
                    } catch (Exception e3) {
                        Object error = e3 instanceof UEException ? e3.getMessage() : "连接引擎出错";
                        Map<String, Object> emap = new HashMap<>();
                        emap.put("error", error);
                        emap.put("status", 3);
                        if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
                            emap.put("availErr", error);
                            emap.put("availStatus", 3);
                        }
                        emap.put("devid", devid);
                        this.webMapper.updateTaskDevice(emap);
                        this.LOG.error("", e3);
                    }
                } catch (Throwable th) {
                    if (session != null) {
                        session.close();
                    }
                    throw th;
                }
            } catch (Exception e4) {
                session.rollback();
                throw e4;
            }
        }
    }

    public void start(Integer devid, Integer taskId) throws Exception {
        Task task = this.webMapper.getTaskById(taskId);
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String licType = ObjectUtil.getString(params.get("type"), "");
        if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
            try {
                startWeb(devid);
                return;
            } catch (Exception e) {
                this.LOG.error("网站安全监控出错", e);
                return;
            }
        }
        try {
            if (task.getDest().contains("bug") || task.getDest().contains("horse") || task.getDest().contains("keyword") || task.getDest().contains("fish")) {
                startWeb(devid);
            }
        } catch (Exception e2) {
            this.LOG.error("网站安全监控出错", e2);
        }
        try {
            if (task.getDest().contains("tamper")) {
                startTamper(devid);
            }
        } catch (Exception e3) {
            this.LOG.error("篡改扫描出错", e3);
        }
        try {
            if (task.getDest().contains("avail")) {
                startAvail(devid);
            }
        } catch (Exception e4) {
            this.LOG.error("可用性扫描出错", e4);
        }
    }

    private void stopWeb(Integer devid, String scanType, Task task) throws Exception {
        Map<Object, Object> availMap;
        Map<Object, Object> availMap2;
        Map<String, Object> dev = this.webMapper.getTaskDevById(devid);
        if (dev == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        String enStr = "";
        String localStr = "";
        String statusStr = "";
        int scanCount = 0;
        if ("bug".equals(scanType) || "onceBug".equals(scanType)) {
            enStr = "engineId";
            localStr = "localEid";
            statusStr = "status";
            scanCount = ObjectUtil.getInt(dev.get("scanCount"), 0);
        } else if ("tamper".equals(scanType)) {
            enStr = "tamperEngineid";
            localStr = "tamperEid";
            statusStr = "tamperStatus";
            scanCount = ObjectUtil.getInt(dev.get("tScanCount"), 0);
        } else if ("avail".equals(scanType)) {
            enStr = "availEngineid";
            localStr = "availEid";
            statusStr = "availStatus";
            scanCount = ObjectUtil.getInt(dev.get("aScanCount"), 0);
        }
        String eid = ObjectUtil.getString(dev.get(enStr), (String) null);
        int status = ObjectUtil.getInt(dev.get(statusStr), 0);
        String staStr = statusStr;
        if (status == 1 || status == 4) {
            try {
                this.engine.webStop(eid, ObjectUtil.getInt(dev.get(localStr)).intValue());
                Map<String, Object> dmap = new HashMap<>();
                dmap.put("devid", devid);
                dmap.put(staStr, 0);
                if (task.getType().intValue() == 1) {
                    dmap.put("tamperStatus", 0);
                    dmap.put("availStatus", 0);
                }
                this.webMapper.updateTaskDevice(dmap);
                if ("onceBug".equals(scanType)) {
                    if (scanCount != 1) {
                        this.bugMapper.delUrl(devid);
                        List<Map<String, Object>> oldBug = this.bugMapper.getBugByDev(devid);
                        this.bugMapper.delBug(devid);
                        this.bugMapper.copyUrl2ToUrl(devid);
                        this.bugMapper.copyResult(devid);
                        this.bugMapper.delUrl2(devid);
                        this.bugMapper.delBug2(devid);
                        if (oldBug != null && oldBug.size() > 0) {
                            this.bugMapper.insertBug2(oldBug);
                        }
                        File bugUrlFile = task.getType().intValue() == 1 ? Constant.WEB_SCAN_URL : Constant.WEB_SCAN_BUGURL;
                        FileUtils.deleteDirectory(new File(bugUrlFile, new StringBuilder().append(devid).toString()));
                        File furl = new File(bugUrlFile, "temp" + devid);
                        furl.renameTo(new File(bugUrlFile, new StringBuilder().append(devid).toString()));
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUG, "oldbug" + devid));
                        File oldBugFile = new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(devid).toString());
                        oldBugFile.renameTo(new File(Constant.WEB_SCAN_BUG, "oldbug" + devid));
                        File fbug = new File(Constant.WEB_SCAN_BUG, "temp" + devid);
                        fbug.renameTo(new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(devid).toString()));
                    }
                    Date currDate = new Date();
                    for (Map<Object, Object> bugCount : this.bugMapper.bugStatistics(devid)) {
                        this.bugMapper.saveStatistics(devid, Integer.valueOf(ObjectUtil.getInt(bugCount.get("type"), 0)), ObjectUtil.getLong(bugCount.get("num"), 0L), currDate);
                    }
                    boolean bl = false;
                    Map<Object, Object> noAccess = this.bugMapper.getAvailNoAccess(devid);
                    if (noAccess != null && noAccess.size() > 0) {
                        if (this.bugMapper.availNoAccessCount(devid) >= 50) {
                            this.bugMapper.delOneNoAccessSta(devid);
                        }
                        this.bugMapper.insertAvailSta(noAccess);
                        bl = true;
                    }
                    if (!bl && (availMap2 = this.bugMapper.getAvail(devid)) != null && availMap2.size() > 0) {
                        if (this.bugMapper.availStaCount(devid) >= 10) {
                            this.bugMapper.delOneAvailSta(devid);
                        }
                        this.bugMapper.insertAvailSta(availMap2);
                    }
                    sbrOemXml(devid);
                    return;
                }
                if ("bug".equals(scanType)) {
                    if (scanCount != 1) {
                        this.bugMapper.delUrl(devid);
                        List<Map<String, Object>> oldBug2 = this.bugMapper.getBugByDev(devid);
                        this.bugMapper.delBug(devid);
                        this.bugMapper.copyUrl2ToUrl(devid);
                        this.bugMapper.copyResult(devid);
                        this.bugMapper.delUrl2(devid);
                        this.bugMapper.delBug2(devid);
                        if (oldBug2 != null && oldBug2.size() > 0) {
                            this.bugMapper.insertBug2(oldBug2);
                        }
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUGURL, new StringBuilder().append(devid).toString()));
                        File furl2 = new File(Constant.WEB_SCAN_BUGURL, "temp" + devid);
                        furl2.renameTo(new File(Constant.WEB_SCAN_BUGURL, new StringBuilder().append(devid).toString()));
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUG, "oldbug" + devid));
                        File oldBugFile2 = new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(devid).toString());
                        oldBugFile2.renameTo(new File(Constant.WEB_SCAN_BUG, "oldbug" + devid));
                        File fbug2 = new File(Constant.WEB_SCAN_BUG, "temp" + devid);
                        fbug2.renameTo(new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(devid).toString()));
                    }
                    Date currDate2 = new Date();
                    for (Map<Object, Object> bugCount2 : this.bugMapper.bugStatistics(devid)) {
                        this.bugMapper.saveStatistics(devid, Integer.valueOf(ObjectUtil.getInt(bugCount2.get("type"), 0)), ObjectUtil.getLong(bugCount2.get("num"), 0L), currDate2);
                    }
                    sbrOemXml(devid);
                    return;
                }
                if ("tamper".equals(scanType)) {
                    if (scanCount != 1) {
                        this.bugMapper.delUrlTamper(devid);
                        this.bugMapper.copyUrlTamper(devid);
                        this.bugMapper.delUrlTamper2(devid);
                        FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_URL, new StringBuilder().append(devid).toString()));
                        File f = new File(Constant.WEB_SCAN_URL, "temp" + devid);
                        f.renameTo(new File(Constant.WEB_SCAN_URL, new StringBuilder().append(devid).toString()));
                        return;
                    }
                    return;
                }
                if ("avail".equals(scanType)) {
                    boolean bl2 = false;
                    Map<Object, Object> noAccess2 = this.bugMapper.getAvailNoAccess(devid);
                    if (noAccess2 != null && noAccess2.size() > 0) {
                        if (this.bugMapper.availNoAccessCount(devid) >= 50) {
                            this.bugMapper.delOneNoAccessSta(devid);
                        }
                        this.bugMapper.insertAvailSta(noAccess2);
                        bl2 = true;
                    }
                    if (!bl2 && (availMap = this.bugMapper.getAvail(devid)) != null && availMap.size() > 0) {
                        if (this.bugMapper.availStaCount(devid) >= 10) {
                            this.bugMapper.delOneAvailSta(devid);
                        }
                        this.bugMapper.insertAvailSta(availMap);
                    }
                }
            } catch (Exception e) {
                this.LOG.error("网站扫描引擎停止错误：", e);
                throw e;
            }
        }
    }

    public void stop(Integer devid, Integer taskId) throws Exception {
        stopDev(devid, taskId);
        Map<String, Object> waitingDev = this.bugMapper.getWaitingDev(devid);
        if (waitingDev != null && waitingDev.size() > 0) {
            if (ObjectUtil.getInt(waitingDev.get("scanType")).intValue() == 1) {
                start(ObjectUtil.getInt(waitingDev.get("id")), ObjectUtil.getInt(waitingDev.get("taskId")));
                return;
            }
            String dest = ObjectUtil.getString(waitingDev.get("dest"), "");
            int bugStatus = ObjectUtil.getInt(waitingDev.get("status")).intValue();
            int tamperStatus = ObjectUtil.getInt(waitingDev.get("tamperStatus")).intValue();
            int aStatus = ObjectUtil.getInt(waitingDev.get("availStatus")).intValue();
            if (dest.contains("avail") && aStatus == 4) {
                startAvail(devid);
            }
            if (dest.contains("bug") && bugStatus == 4) {
                startWeb(devid);
            }
            if (dest.contains("tamper") && tamperStatus == 4) {
                startTamper(devid);
            }
        }
    }

    private void stopDev(Integer devid, Integer taskId) throws Exception {
        Task task = this.webMapper.getTaskById(taskId);
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String licType = params.get("type");
        if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
            try {
                stopWeb(devid, "onceBug", task);
                return;
            } catch (Exception e) {
                if (e instanceof UEException) {
                    throw e;
                }
                throw new UEException("停止网站安全监控出错", e);
            }
        }
        try {
            stopWeb(devid, "bug", task);
            try {
                stopWeb(devid, "tamper", task);
                try {
                    stopWeb(devid, "avail", task);
                } catch (Exception e2) {
                    if (e2 instanceof UEException) {
                        throw e2;
                    }
                    throw new UEException("停止可用性监控出错", e2);
                }
            } catch (Exception e3) {
                if (e3 instanceof UEException) {
                    throw e3;
                }
                throw new UEException("停止篡改监控出错", e3);
            }
        } catch (Exception e4) {
            if (e4 instanceof UEException) {
                throw e4;
            }
            throw new UEException("停止网站安全监控出错", e4);
        }
    }

    public void startScanTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = this.webMapper.getTaskDevByTid(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            start(ObjectUtil.getInt(dev.get("id")), taskId);
        }
    }

    public void startScanTask(Integer taskId, String scanType) throws Exception {
        List<Map<String, Object>> taskDevList = this.webMapper.getTaskDevByTid(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            if (scanType.equals("bug")) {
                startWeb(ObjectUtil.getInt(dev.get("id")));
            } else if (scanType.equals("tamper")) {
                startTamper(ObjectUtil.getInt(dev.get("id")));
            } else if (scanType.equals("avail")) {
                startAvail(ObjectUtil.getInt(dev.get("id")));
            }
        }
    }

    public void stopScanTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = this.webMapper.getNeedStopTaskDevs(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            Integer devid = ObjectUtil.getInt(dev.get("id"));
            try {
                int status = ObjectUtil.getInt(dev.get("status"), 0);
                int tamperStatus = ObjectUtil.getInt(dev.get("tamperStatus"), 0);
                if (status == 4 || tamperStatus == 4) {
                    dev.put("status", 0);
                    dev.put("tamperStatus", 0);
                    dev.put("availStatus", 0);
                    dev.put("devid", devid);
                    this.webMapper.updateTaskDevice(dev);
                } else {
                    stopDev(devid, taskId);
                }
            } catch (Exception e) {
                if (e instanceof UEException) {
                    throw e;
                }
                throw new UEException("停止出错", e);
            }
        }
        Task t = this.webMapper.getTaskById(taskId);
        if (ObjectUtil.getInt(t.getAlarmType(), 0) == 1) {
            AlermJob.alermTask(taskId);
        }
    }

    public void delDev(Integer devId) throws Exception {
        Map<String, Object> webMap = this.webMapper.getTaskDevById(devId);
        if (1 == ObjectUtil.getInt(webMap.get("status")).intValue() || 1 == ObjectUtil.getInt(webMap.get("tamperStatus")).intValue() || 1 == ObjectUtil.getInt(webMap.get("availStatus")).intValue()) {
            throw new UEException("正在扫描，请先停止后再删除！");
        }
        String eid = ObjectUtil.getString(webMap.get("engineId"), "");
        if (StringUtils.isNotBlank(eid)) {
            this.engine.webDelete(eid, ObjectUtil.getInt(webMap.get("localEid")).intValue());
        }
        SqlSession session = null;
        try {
            try {
                session = MybatisUtil.sqlSessionFactory.openSession(true);
                WebBugMapper webBugMapper = (WebBugMapper) session.getMapper(WebBugMapper.class);
                WebMapper webMapper = (WebMapper) session.getMapper(WebMapper.class);
                webBugMapper.delAvail(devId);
                webBugMapper.delUrl(devId);
                webBugMapper.delUrl2(devId);
                webBugMapper.delBug(devId);
                webBugMapper.delBug2(devId);
                webBugMapper.delTamper(devId);
                webBugMapper.delUrlTamper(devId);
                webBugMapper.delUrlTamper2(devId);
                webMapper.delTaskDevById(devId);
                session.commit();
                if (session != null) {
                    session.close();
                }
                FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_URL, new StringBuilder().append(devId).toString()));
                FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(devId).toString()));
                FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUG, "oldbug" + devId));
                FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_TAMPER, new StringBuilder().append(devId).toString()));
                FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUGURL, new StringBuilder().append(devId).toString()));
            } catch (Exception e) {
                if (session != null) {
                    session.rollback();
                }
                throw e;
            }
        } catch (Throwable th) {
            if (session != null) {
                session.close();
            }
            throw th;
        }
    }

    public void addDev(HttpSession session, String devIds, Integer taskId) throws Exception {
        String[] devIdArr = devIds.split(",");
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "webscan");
        int maxdevice = licCmp.getMaxdevice();
        int devIpCount = devIdArr.length;
        if (maxdevice > 0 && this.webMapper.getCountByType(ReportService.REPORT_STATE_SUCCESS) + devIpCount > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        List<Integer> devices = new ArrayList<>();
        for (String devid : devIdArr) {
            Map<String, Object> devMap = this.deviceMapper.getDevById(ObjectUtil.getInt(devid));
            devMap.put("taskId", taskId);
            devMap.put("type", 1);
            Map<String, Object> confMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(devMap.get("confContent"), ""), HashMap.class);
            devMap.put("confContent", JsonUtil.MAPPER.writeValueAsString(confMap.get(ReportService.REPORT_STATE_SUCCESS)));
            this.webMapper.insertTaskDevice(devMap);
            devices.add(ObjectUtil.getInt(devMap.get("id")));
        }
        for (Integer devid2 : devices) {
            Map<String, Object> devMap2 = this.webMapper.getTaskDevById(devid2);
            Task task = this.webMapper.getTaskById(taskId);
            if (task != null && task.getType().intValue() == 1) {
                User user = (User) session.getAttribute("userInfo");
                boolean bl = true;
                try {
                    startWeb(ObjectUtil.getInt(devMap2.get("id")));
                } catch (Exception e) {
                    bl = false;
                    this.LOG.error("扫描出错", e);
                }
                if (bl) {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描网站安全监控任务", "", 1, "扫描成功");
                } else {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描网站安全监控任务", "", 2, "扫描失败");
                }
            }
        }
    }

    public void manualAddWeb(HttpSession session, String url, Integer taskId) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "webscan");
        int maxdevice = licCmp.getMaxdevice();
        if (maxdevice > 0 && this.webMapper.getCountByType(ReportService.REPORT_STATE_SUCCESS) + 1 > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        Task task = this.webMapper.getTaskById(taskId);
        User user = (User) session.getAttribute("userInfo");
        Map<String, Object> web = new HashMap<>();
        web.put("name", url.length() > 50 ? url.substring(0, 50) : url);
        web.put("type", 1);
        web.put("taskId", taskId);
        web.put("ip", url);
        web.put("regionCid", user.getRegionCid());
        web.put("regionSid", Integer.valueOf(user.getRegionSid() == null ? 110000 : user.getRegionSid().intValue()));
        web.put("confContent", "{\"url\":\"" + url + "\"}");
        this.webMapper.insertTaskDevice(web);
        if (task != null && task.getType().intValue() == 1) {
            boolean bl = true;
            try {
                startWeb(ObjectUtil.getInt(web.get("id")));
            } catch (Exception e) {
                bl = false;
                this.LOG.error("扫描出错", e);
            }
            if (bl) {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描网站安全监控任务", "", 1, "扫描成功");
            } else {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描网站安全监控任务", "", 2, "扫描失败");
            }
        }
    }

    public List<Map<String, Object>> getDevDetailByTid(Integer id) throws Exception {
        return this.webMapper.getDevDetailByTid(id);
    }

    public List<Map<String, Object>> getBugByTWidAndType(Integer twid, Integer type) throws Exception {
        return this.webMapper.getBugByTWidAndType(twid, type);
    }

    public List<Map<String, Object>> getTamperByTWid(Integer twid) throws Exception {
        return this.webMapper.getTamperByTWid(twid);
    }

    public Map<String, Object> getAvailByTWid(Integer twid) throws Exception {
        return this.webMapper.getAvailByTWid(twid);
    }

    public List<Map<String, Object>> bugCount(Integer twid) throws Exception {
        return this.webMapper.bugCount(twid);
    }

    public List<String> getBugTimeByTwid(Integer twid) throws Exception {
        return this.webMapper.getBugTimeByTwid(twid);
    }

    public List<Map<String, Object>> getBugStaByTwid(Integer twid) throws Exception {
        return this.webMapper.getBugStaByTwid(twid);
    }

    public List<Map<String, Object>> webStruct(Integer deviceid, String[] linkTypes) throws Exception {
        List<Map<String, Object>> webStructs = this.webMapper.webStruct(deviceid, linkTypes);
        Collections.sort(webStructs, new Comparator<Map<String, Object>>() { // from class: com.datacloudsec.scan.service.impl.WebService.6
            @Override // java.util.Comparator
            public int compare(Map<String, Object> a, Map<String, Object> b) {
                return ObjectUtil.getString(a.get("url"), "").toUpperCase().compareTo(ObjectUtil.getString(b.get("url"), "").toUpperCase());
            }
        });
        return webStructs;
    }

    private void delTask(HttpSession session, Integer id, Integer version) throws Exception {
        File f;
        List<Map<String, Object>> devList = this.webMapper.getTaskDevByTid(id);
        Exception ex = null;
        int count = 0;
        for (Map<String, Object> dev : devList) {
            try {
                String engineId = ObjectUtil.getString(dev.get("engineId"), "");
                if (StringUtils.isNotBlank(engineId)) {
                    this.engine.webDelete(engineId, ObjectUtil.getInt(dev.get("localEid")).intValue());
                }
                count++;
            } catch (Exception e) {
                this.LOG.error("", e);
                ex = e;
            }
        }
        if (count == 0) {
            throw ex;
        }
        Iterator<Map<String, Object>> it = devList.iterator();
        while (it.hasNext()) {
            Integer webid = ObjectUtil.getInt(it.next().get("id"));
            this.webBugMapper.delAvail(webid);
            this.webBugMapper.delAvailSta(webid);
            this.webBugMapper.delUrl(webid);
            this.webBugMapper.delUrl2(webid);
            this.webBugMapper.delBug(webid);
            this.webBugMapper.delBug2(webid);
            this.webBugMapper.delTamper(webid);
            this.webBugMapper.delUrlTamper(webid);
            this.webBugMapper.delUrlTamper2(webid);
            this.webBugMapper.clearStatistics(webid);
            FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_URL, new StringBuilder().append(webid).toString()));
            FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(webid).toString()));
            FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUG, "oldbug" + webid));
            FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_TAMPER, new StringBuilder().append(webid).toString()));
            FileUtils.deleteDirectory(new File(Constant.WEB_SCAN_BUGURL, new StringBuilder().append(webid).toString()));
        }
        Task task = this.webMapper.getTaskById(id);
        String confStr = task.getConfContent();
        if (StringUtils.isNotBlank(confStr)) {
            Map<String, Object> conf = (Map) JsonUtil.MAPPER.readValue(confStr, Map.class);
            String guesspaths = ObjectUtil.getString(conf.get("guesspaths"), "");
            if (conf.containsKey("guesspaths") && StringUtils.isNotBlank(guesspaths) && (f = new File(Constant.GUESSPATHS_DIR, guesspaths)) != null && f.exists()) {
                f.delete();
            }
        }
        stopWebTimer(session, id);
        this.webMapper.delTaskDevByTid(id);
        Integer rcount = Integer.valueOf(this.webMapper.delete(id, version, DataRule.getRuleWhere(session, "t_task")));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public Map<String, Object> getKeywordsByTid(Integer id) throws Exception {
        return this.webMapper.getKeywordsByTid(id);
    }

    public Map<String, Object> getBugById(Integer id) throws Exception {
        return this.webMapper.getBugById(id);
    }

    public Map<String, Object> getTamperById(Integer id) throws Exception {
        return this.webMapper.getTamperById(id);
    }

    public List<Map<String, Object>> fishBug(Integer id) throws Exception {
        return this.webMapper.fishBug(id);
    }

    public List<Map<String, Object>> newBug(Integer id) throws Exception {
        return this.webMapper.newBug(id);
    }

    public List<Map<String, Object>> recovered(Integer id) throws Exception {
        return this.webMapper.recovered(id);
    }

    public Map<String, Object> getBug2ById(Integer id) throws Exception {
        return this.webMapper.getBug2ById(id);
    }

    public int markBugErr(Integer id, Integer status) throws Exception {
        return this.webMapper.markBugErr(id, status);
    }

    public File webBackup(Integer taskId) throws Exception {
        File dir = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File f = new File(Constant.TEMP_DIR, String.valueOf(System.nanoTime()) + ".webtask");
        try {
            try {
                SerializeUtil.serializeObj(new File(dir, "task.backup"), this.webMapper.getTaskById(taskId));
                List<Map<String, Object>> devList = this.webMapper.getTaskDevByTid(taskId);
                for (Map<String, Object> dev : devList) {
                    Integer devid = ObjectUtil.getInt(dev.get("id"));
                    File devDir = new File(dir, new StringBuilder().append(devid).toString());
                    if (!devDir.exists()) {
                        devDir.mkdirs();
                    }
                    SerializeUtil.serializeObj(new File(devDir, "dev.backup"), dev);
                    SerializeUtil.serializeObj(new File(devDir, "sta.backup"), this.webMapper.getBugStaByDevId(devid));
                    SerializeUtil.serializeObj(new File(devDir, "avail.backup"), this.webMapper.getAvailByTWid(devid));
                    SerializeUtil.serializeObj(new File(devDir, "availsta.backup"), this.webMapper.getAvailStaByDevId(devid));
                    List<Map<String, Object>> bugList = this.webMapper.getBugByDevid(devid);
                    if (bugList != null && bugList.size() > 0) {
                        File bugDir = new File(devDir, "bug");
                        if (!bugDir.exists()) {
                            bugDir.mkdirs();
                        }
                        FileUtils.copyDirectory(new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(devid).toString()), bugDir);
                        SerializeUtil.serializeObj(new File(devDir, "bug.backup"), bugList);
                    }
                    List<Map<String, Object>> bug2List = this.webMapper.getBug2ByDevid(devid);
                    if (bug2List != null && bug2List.size() > 0) {
                        File bugDir2 = new File(devDir, "bug2");
                        if (!bugDir2.exists()) {
                            bugDir2.mkdirs();
                        }
                        FileUtils.copyDirectory(new File(Constant.WEB_SCAN_BUG, "oldbug" + devid), bugDir2);
                        SerializeUtil.serializeObj(new File(devDir, "bug2.backup"), bug2List);
                    }
                    List<Map<String, Object>> urlList = this.webMapper.getUrlByDevid(devid);
                    if (urlList != null && urlList.size() > 0) {
                        File urlDir = new File(devDir, "url");
                        if (!urlDir.exists()) {
                            urlDir.mkdirs();
                        }
                        File scanurl = new File(Constant.WEB_SCAN_URL, new StringBuilder().append(devid).toString());
                        if (scanurl != null && scanurl.exists()) {
                            FileUtils.copyDirectory(scanurl, urlDir);
                            SerializeUtil.serializeObj(new File(devDir, "url.backup"), urlList);
                        }
                        File bugurl = new File(Constant.WEB_SCAN_BUGURL, new StringBuilder().append(devid).toString());
                        if (bugurl != null && bugurl.exists()) {
                            File bugurlrDir = new File(devDir, "bugurl");
                            if (!bugurlrDir.exists()) {
                                bugurlrDir.mkdirs();
                            }
                            FileUtils.copyDirectory(bugurl, bugurlrDir);
                        }
                    }
                    List<Map<String, Object>> tampers = this.webMapper.getTamperByDevid(devid);
                    if (tampers != null && tampers.size() > 0) {
                        File tamperDir = new File(devDir, "tamper");
                        if (!tamperDir.exists()) {
                            tamperDir.mkdirs();
                        }
                        FileUtils.copyDirectory(new File(Constant.WEB_SCAN_TAMPER, new StringBuilder().append(devid).toString()), tamperDir);
                        SerializeUtil.serializeObj(new File(devDir, "tamper.backup"), tampers);
                    }
                }
                ComonZipUtil.zip(dir.getPath(), f.getPath());
                return f;
            } catch (Exception e) {
                throw e;
            }
        } finally {
            if (dir != null && dir.exists()) {
                FileUtils.deleteDirectory(dir);
            }
        }
    }

    @Transactional
    public void webRestore(HttpSession session, File f) throws Exception {
        File unzipFile = new File(Constant.COMMON_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        ComonZipUtil.unzip(f, unzipFile);
        File taskFile = new File(unzipFile, "task.backup");
        Task t = (Task) SerializeUtil.deserializeObj(taskFile);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.webMapper.getTaskCountByName(t.getName(), 0, uid, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("webTaskAlready:" + unzipFile.getName());
        }
        try {
            restore(unzipFile, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(unzipFile);
            throw e;
        }
    }

    private void restore(File unzipFile, Task t) throws Exception {
        Map<String, Object> device;
        if (unzipFile == null || t == null) {
            return;
        }
        this.webMapper.insert(t);
        for (File taskDir : unzipFile.listFiles()) {
            if (!taskDir.getName().equals("task.backup") && (device = (Map) SerializeUtil.deserializeObj(new File(taskDir, "dev.backup"))) != null) {
                device.put("taskId", t.getId());
                this.webMapper.inserTaskDevById(device);
                Integer devId = ObjectUtil.getInt(device.get("id"));
                Map<String, Object> avail = (Map) SerializeUtil.deserializeObj(new File(taskDir, "avail.backup"));
                if (avail != null && avail.size() > 0) {
                    this.bugMapper.insertAvail(devId, ObjectUtil.getString(avail.get("code"), ""), ObjectUtil.getInt(avail.get("status")), ObjectUtil.getInt(avail.get("dnsTime")), ObjectUtil.getInt(avail.get("connectTime")), ObjectUtil.getInt(avail.get("responseTime")), ObjectUtil.getInt(avail.get("type")), ObjectUtil.getString(avail.get("remoteIp"), ""), ObjectUtil.getString(avail.get("preRemoteIp"), ""), ObjectUtil.getString(avail.get("server"), ""), ObjectUtil.getString(avail.get("xpowerdby"), ""), ObjectUtil.getString(avail.get("title"), ""));
                }
                List<Map<String, Object>> availsta = (List) SerializeUtil.deserializeObj(new File(taskDir, "availsta.backup"));
                if (CollectionUtils.isNotEmpty(availsta)) {
                    this.webMapper.insertAvailStas(devId, availsta);
                }
                List<Map<String, Object>> sta = (List) SerializeUtil.deserializeObj(new File(taskDir, "sta.backup"));
                if (CollectionUtils.isNotEmpty(sta)) {
                    this.webMapper.insertWebSta(devId, sta);
                }
                List<Map<String, Object>> tamper = (List) SerializeUtil.deserializeObj(new File(taskDir, "tamper.backup"));
                if (CollectionUtils.isNotEmpty(tamper)) {
                    this.webMapper.inserWebTamper(devId, tamper);
                    File tamperFile = new File(taskDir, "tamper");
                    FileUtils.copyDirectory(tamperFile, new File(Constant.WEB_SCAN_TAMPER, new StringBuilder().append(devId).toString()));
                }
                List<Map<String, Object>> bug = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug.backup"));
                if (bug != null && bug.size() > 0) {
                    for (Map<String, Object> map : bug) {
                        String rawDataPath = ObjectUtil.getString(map.get("rawDataPath"), "");
                        if (!"".equals(rawDataPath)) {
                            String[] rowdata = rawDataPath.split("/");
                            map.put("rawDataPath", devId + "/" + rowdata[1]);
                        }
                        String testDataPath = ObjectUtil.getString(map.get("testDataPath"), "");
                        if (!"".equals(testDataPath)) {
                            String[] testdata = testDataPath.split("/");
                            map.put("testDataPath", devId + "/" + testdata[1]);
                        }
                    }
                    this.webMapper.inserWebBugs(devId, bug);
                    File bugFile = new File(taskDir, "bug");
                    FileUtils.copyDirectory(bugFile, new File(Constant.WEB_SCAN_BUG, new StringBuilder().append(devId).toString()));
                }
                List<Map<String, Object>> bug2 = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug2.backup"));
                if (CollectionUtils.isNotEmpty(bug2)) {
                    for (Map<String, Object> map2 : bug2) {
                        String rawDataPath2 = ObjectUtil.getString(map2.get("rawDataPath"), "");
                        if (!"".equals(rawDataPath2)) {
                            String[] rowdata2 = rawDataPath2.split("/");
                            map2.put("rawDataPath", devId + "/" + rowdata2[1]);
                        }
                        String testDataPath2 = ObjectUtil.getString(map2.get("testDataPath"), "");
                        if (!"".equals(testDataPath2)) {
                            String[] testdata2 = testDataPath2.split("/");
                            map2.put("testDataPath", devId + "/" + testdata2[1]);
                        }
                    }
                    this.webMapper.inserWebBugs2(devId, bug2);
                    File bugFile2 = new File(taskDir, "bug2");
                    FileUtils.copyDirectory(bugFile2, new File(Constant.WEB_SCAN_BUG, "oldbug" + devId));
                }
                List<Map<String, Object>> url = (List) SerializeUtil.deserializeObj(new File(taskDir, "url.backup"));
                if (CollectionUtils.isNotEmpty(url)) {
                    for (Map<String, Object> map3 : url) {
                        String rowDataPath = ObjectUtil.getString(map3.get("rowDataPath"), "");
                        if (!"".equals(rowDataPath)) {
                            String[] rowdata3 = rowDataPath.split("/");
                            map3.put("rowDataPath", devId + "/" + rowdata3[1]);
                        }
                    }
                    this.webMapper.inserWebUrl(devId, url);
                    File urlFile = new File(taskDir, "url");
                    FileUtils.copyDirectory(urlFile, new File(Constant.WEB_SCAN_URL, new StringBuilder().append(devId).toString()));
                    File bugurlFile = new File(taskDir, "bugurl");
                    if (bugurlFile != null && bugurlFile.exists()) {
                        FileUtils.copyDirectory(bugurlFile, new File(Constant.WEB_SCAN_BUGURL, new StringBuilder().append(devId).toString()));
                    }
                }
            }
        }
        String dest = t.getDest();
        if (dest.contains("bug") || dest.contains("horse") || dest.contains("keyword") || dest.contains("fish")) {
            startWebScanTimer(t.getId(), t.getType(), t.getPeriodTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime(), "bug");
        }
        if (dest.contains("tamper")) {
            startWebScanTimer(t.getId(), t.getType(), t.getTamperTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime(), "tamper");
        }
        if (dest.contains("avail")) {
            startWebScanTimer(t.getId(), t.getType(), t.getAvailTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime(), "avail");
        }
        startWebAlermTimer(t.getId(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime(), "all");
        FileUtils.deleteDirectory(unzipFile);
    }

    @Transactional
    public void webEnter(HttpSession session, String filename) throws Exception {
        File f = new File(Constant.COMMON_DIR, filename);
        if (f == null || !f.exists()) {
            this.LOG.error("网站恢复，文件不存在！");
            return;
        }
        User u = (User) session.getAttribute("userInfo");
        Task t = (Task) SerializeUtil.deserializeObj(new File(f, "task.backup"));
        t.setName(String.valueOf(t.getName()) + System.nanoTime());
        t.setUid(u.getId());
        try {
            restore(f, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(f);
            throw e;
        }
    }

    public File sbrOemXml(Integer deviceid) throws Exception {
        Properties pro = (Properties) InitSystemTask.servletContext.getAttribute("oem");
        if (!pro.getProperty("copyright", "").contains("圣博润")) {
            return null;
        }
        Config config = Config.getInstance();
        Map<String, Object> device = this.webMapper.getTaskDevById(deviceid);
        Document document = DocumentHelper.createDocument();
        Element root = document.addElement("result");
        Element scheme = root.addElement("scheme");
        Element tool_info = scheme.addElement("tool_info");
        tool_info.addAttribute("ToolVersion", ObjectUtil.getString("V" + config.getString("version", ""), "", 20));
        tool_info.addAttribute("ToolCategory", "005");
        tool_info.addAttribute("ToolName", pro.getProperty("sysname", ""));
        tool_info.addAttribute("ToolCode", "LsWebScan.exe");
        tool_info.addAttribute("CorpName", "北京圣博润高新技术股份有限公司");
        tool_info.addAttribute("CorpCode", "BJSBRGXJSGFYXGS");
        tool_info.addAttribute("Category", "12");
        tool_info.addAttribute("Code", "12-01");
        Element operation_info = scheme.addElement("operation_info");
        String confStr = ObjectUtil.getString(device.get("confContent"), "");
        if (!"".equals(confStr)) {
            Map<String, Object> confContent = (Map) JsonUtil.MAPPER.readValue(confStr, HashMap.class);
            operation_info.addAttribute("DestHostName", ObjectUtil.getString(confContent.get("url"), "", 100));
            operation_info.addAttribute("DestMac", "");
            operation_info.addAttribute("DestIp", "");
            operation_info.addAttribute("SrcHostName", "");
            operation_info.addAttribute("SrcIp", "");
            operation_info.addAttribute("SrcOs", "");
            operation_info.addAttribute("Stamp", new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        }
        Element report = root.addElement("report");
        Element summary = report.addElement("summary");
        summary.addAttribute("title", "报告摘要");
        Element issue_stat = summary.addElement("issue_stat");
        issue_stat.addAttribute("title", "网站漏洞类型统计");
        Map<String, String> bug = new HashMap<>();
        bug.put("SQL注入漏洞", "否");
        bug.put("中间件", "否");
        bug.put("信息泄露", "否");
        bug.put("其他漏洞", "否");
        bug.put("危险端口", "否");
        bug.put("后台管理地址泄露漏洞", "否");
        bug.put("攻击痕迹", "否");
        bug.put("文件上传漏洞", "否");
        bug.put("文件包含", "否");
        bug.put("目录遍历", "否");
        bug.put("第三方插件漏洞", "否");
        bug.put("网站暗链", "否");
        bug.put("网站木马", "否");
        bug.put("跨站脚本", "否");
        bug.put("配置文件漏洞", "否");
        bug.put("页面篡改", "否");
        List<Map<String, Object>> weblist = this.webMapper.getSbrOemWeb(deviceid);
        for (Map<String, Object> web : weblist) {
            String title = ObjectUtil.getString(web.get("title"), "");
            String family = ObjectUtil.getString(web.get("family"), "");
            Integer found = Integer.valueOf(ObjectUtil.getInt(web.get("found"), 0));
            if ("A1[注入]".equalsIgnoreCase(family) && found.intValue() == 1) {
                bug.put("SQL注入漏洞", "是");
            } else if ((title.contains("Weblogic") || title.contains("Tomcat") || title.contains("Nginx") || title.contains("IIS")) && found.intValue() == 1) {
                bug.put("中间件", "是");
            } else if ("A6[敏感信息泄露]".equalsIgnoreCase(family) && found.intValue() == 1) {
                bug.put("信息泄露", "是");
            } else if ("A0[其他]".equalsIgnoreCase(family) && found.intValue() == 1) {
                bug.put("其他漏洞", "是");
            } else if ("管理后台登陆入口".equals(title) && found.intValue() == 1) {
                bug.put("后台管理地址泄露漏洞", "是");
            } else if (title.contains("文件上传") && found.intValue() == 1) {
                bug.put("文件上传漏洞", "是");
            } else if ((title.contains("远程文件包含漏洞") || title.contains("本地文件包含漏洞")) && found.intValue() == 1) {
                bug.put("文件包含", "是");
            } else if (title.contains("目录遍历漏洞(可访问任意目录下文件)") && found.intValue() == 1) {
                bug.put("目录遍历", "是");
            } else if ("A9[使用含有已知漏洞的组件]".equalsIgnoreCase(family) && found.intValue() == 1) {
                bug.put("第三方插件漏洞", "是");
            } else if (title.contains("脚本木马(Webshell)") && found.intValue() == 1) {
                bug.put("网站木马", "是");
            } else if ("A3[跨站脚本]".equalsIgnoreCase(family) && found.intValue() == 1) {
                bug.put("跨站脚本", "是");
            } else if ("A5[安全配置错误]".equalsIgnoreCase(family) && found.intValue() == 1) {
                bug.put("配置文件漏洞", "是");
            }
        }
        for (Map.Entry<String, String> e : bug.entrySet()) {
            Element item = issue_stat.addElement("item");
            item.addAttribute("title", e.getKey());
            item.addAttribute("found", e.getValue());
        }
        String fileName = String.valueOf(ObjectUtil.getString(device.get("ip"), "")) + "_" + new SimpleDateFormat("yyyy_MM_dd_HH_mm_ss").format(new Date()) + ".xml";
        Pattern pattern = Pattern.compile("[\\s\\\\/:\\*\\?\\\"<>\\|]");
        Matcher matcher = pattern.matcher(fileName);
        String fileName2 = matcher.replaceAll("");
        File f = new File(Constant.SBR_OEM, ObjectUtil.getString(fileName2, "", 255));
        outputXml(document, f, "GB2312");
        return f;
    }

    private void outputXml(Document doc, File file, String encoding) throws Exception {
        XMLWriter writer = null;
        OutputFormat format = OutputFormat.createPrettyPrint();
        format.setEncoding(encoding);
        File dir = file.getParentFile();
        if (!dir.isDirectory()) {
            dir.mkdirs();
        }
        ByteArrayOutputStream fos = null;
        try {
            try {
                fos = new ByteArrayOutputStream();
                writer = new XMLWriter(fos, format);
                writer.write(doc);
                writer.flush();
                byte[] b = SecretUtil.SM4.encryption(fos.toByteArray(), "&$L(,nfT/%IU@#g".getBytes());
                FileUtils.writeByteArrayToFile(file, b);
                if (writer != null) {
                    writer.close();
                }
                IOUtils.closeQuietly(fos);
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            if (writer != null) {
                writer.close();
            }
            IOUtils.closeQuietly(fos);
            throw th;
        }
    }

    public List<Integer> getTaskStatus(Integer id) throws Exception {
        return this.webMapper.getTaskStatus(id);
    }

    public List<Map<String, Object>> getTamperLevelCount(Integer id) throws Exception {
        return this.webMapper.getTamperLevelCount(id);
    }

    public List<Map<String, Object>> getTamperByDevid(Integer id) throws Exception {
        return this.webMapper.getTamperByDevid(id);
    }

    public List<Map<String, Object>> getKeyWordsByDevid(Integer id) throws Exception {
        return this.webMapper.getKeyWordsByDevid(id);
    }

    public List<Map<String, Object>> getHorseByDevid(Integer id) throws Exception {
        return this.webMapper.getHorseByDevid(id);
    }

    public int markBugFlag(Integer id, Integer flag) throws Exception {
        return this.webMapper.markBugFlag(id, flag);
    }

    public List<Map<String, Object>> getBugsInter(Integer id) throws Exception {
        return this.webMapper.getBugsInter(id);
    }

    public List<Map<String, Object>> getBugListByDevid(Integer id) throws Exception {
        return this.webMapper.getBugListByDevid(id);
    }

    public void proceedStart(Integer devid, Integer taskId) throws Exception {
        Task task = this.webMapper.getTaskById(taskId);
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String licType = ObjectUtil.getString(params.get("type"), "");
        Map<String, Object> device = this.webMapper.getTaskDevById(devid);
        if ("tool".equalsIgnoreCase(licType) || task.getDest().contains("bug") || task.getDest().contains("horse") || task.getDest().contains("keyword") || task.getDest().contains("fish")) {
            if (1 == ObjectUtil.getInt(device.get("status"), 0)) {
                return;
            }
            proceed(task, ObjectUtil.getString(device.get("engineId"), ""), ObjectUtil.getInt(device.get("localEid")), devid, licType);
            device.put("status", 1);
            device.put("devid", devid);
            this.webMapper.updateTaskDevice(device);
        }
        if (task.getDest().contains("tamper")) {
            if (1 == ObjectUtil.getInt(device.get("tamperStatus"), 0)) {
                return;
            }
            try {
                proceed(task, ObjectUtil.getString(device.get("tamperEngineid"), ""), ObjectUtil.getInt(device.get("tamperEid")), devid, licType);
                device.put("tamperStatus", 1);
                device.put("devid", devid);
                this.webMapper.updateTaskDevice(device);
            } catch (Exception e) {
                startTamper(devid);
                this.LOG.error("", e);
            }
        }
        if (task.getDest().contains("avail")) {
            startAvail(devid);
        }
    }

    private void proceed(Task task, String eid, Integer lid, Integer devid, String licType) throws Exception {
        try {
            this.engine.webContinuescan(eid, lid.intValue());
        } catch (Exception e) {
            Object error = e instanceof UEException ? e.getMessage() : "连接引擎出错";
            Map<String, Object> emap = new HashMap<>();
            emap.put("error", error);
            emap.put("status", 3);
            if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
                emap.put("availErr", error);
                emap.put("availStatus", 3);
            }
            emap.put("devid", devid);
            this.webMapper.updateTaskDevice(emap);
            this.LOG.error("继续扫描出错", e);
        }
    }

    public void pause(Integer devid, Integer taskId) throws Exception {
        Task task = this.webMapper.getTaskById(taskId);
        Map<String, Object> device = this.webMapper.getTaskDevById(devid);
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String licType = params.get("type");
        try {
            if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
                this.engine.webStop(ObjectUtil.getString(device.get("engineId"), ""), ObjectUtil.getInt(device.get("localEid"), 0));
                device.put("status", 5);
                this.webMapper.updateTaskDevice(device);
                return;
            }
            String engineId = ObjectUtil.getString(device.get("engineId"), "");
            if (StringUtils.isNotBlank(engineId)) {
                this.engine.webStop(engineId, ObjectUtil.getInt(device.get("localEid"), 0));
            }
            String tamperEngineid = ObjectUtil.getString(device.get("tamperEngineid"), "");
            if (StringUtils.isNotBlank(tamperEngineid)) {
                this.engine.webStop(tamperEngineid, ObjectUtil.getInt(device.get("tamperEid"), 0));
            }
            device.put("availStatus", 5);
            device.put("status", 5);
            device.put("tamperStatus", 5);
            device.put("devid", devid);
            this.webMapper.updateTaskDevice(device);
        } catch (Exception e) {
            Object error = e instanceof UEException ? e.getMessage() : "连接引擎出错";
            Map<String, Object> emap = new HashMap<>();
            emap.put("error", error);
            emap.put("status", 3);
            if (task.getType().intValue() == 1 && "tool".equalsIgnoreCase(licType)) {
                emap.put("availErr", error);
                emap.put("availStatus", 3);
            }
            emap.put("devid", devid);
            this.webMapper.updateTaskDevice(emap);
            this.LOG.error("继续扫描出错", e);
        }
    }

    public void proceedStartTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = this.webMapper.getTaskDevByTid(taskId);
        if (CollectionUtils.isEmpty(taskDevList)) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            proceedStart(ObjectUtil.getInt(dev.get("id")), taskId);
        }
    }

    public void pauseScanTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = this.webMapper.getNeedStopTaskDevs(taskId);
        if (CollectionUtils.isEmpty(taskDevList)) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            Integer devid = ObjectUtil.getInt(dev.get("id"));
            try {
                int status = ObjectUtil.getInt(dev.get("status"), 0);
                int tamperStatus = ObjectUtil.getInt(dev.get("tamperStatus"), 0);
                if (status == 4 || tamperStatus == 4) {
                    dev.put("status", 0);
                    dev.put("tamperStatus", 0);
                    dev.put("availStatus", 0);
                    dev.put("devid", devid);
                    this.webMapper.updateTaskDevice(dev);
                } else {
                    pause(devid, taskId);
                }
            } catch (Exception e) {
                if (e instanceof UEException) {
                    throw e;
                }
                throw new UEException("暂停出错", e);
            }
        }
    }
}
